@@ -86,7 +86,7 @@
 #define KIOCORE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KIOCORE_NO_DEPRECATED
-#  define KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54000
+#  define KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54500
 #endif
 #ifdef KIOCORE_NO_DEPRECATED_WARNINGS
 #  define KIOCORE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KIOCORE_DEPRECATED_WARNINGS_SINCE KIOCORE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KIOCORE_DEPRECATED_WARNINGS_SINCE 0x54000
+#    define KIOCORE_DEPRECATED_WARNINGS_SINCE 0x54500
 #  endif
 #endif
 
@@ -205,6 +205,24 @@
 #else
 #  define KIOCORE_DEPRECATED_VERSION_5_64(text)
 #endif
+
+#if KIOCORE_DEPRECATED_WARNINGS_SINCE >= 0x54100
+#  define KIOCORE_DEPRECATED_VERSION_5_65(text) KIOCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOCORE_DEPRECATED_VERSION_5_65(text)
+#endif
+
+#if KIOCORE_DEPRECATED_WARNINGS_SINCE >= 0x54200
+#  define KIOCORE_DEPRECATED_VERSION_5_66(text) KIOCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOCORE_DEPRECATED_VERSION_5_66(text)
+#endif
+
+#if KIOCORE_DEPRECATED_WARNINGS_SINCE >= 0x54500
+#  define KIOCORE_DEPRECATED_VERSION_5_69(text) KIOCORE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KIOCORE_DEPRECATED_VERSION_5_69(text)
+#endif
 #define KIOCORE_DEPRECATED_VERSION_3(minor, text)      KIOCORE_DEPRECATED_VERSION_3_##minor(text)
 #define KIOCORE_DEPRECATED_VERSION_4(minor, text)      KIOCORE_DEPRECATED_VERSION_4_##minor(text)
 #define KIOCORE_DEPRECATED_VERSION_5(minor, text)      KIOCORE_DEPRECATED_VERSION_5_##minor(text)
